@@ -1,20 +1,31 @@
 use serde::Serialize;
-use std::sync::Arc;
 use twilight_model::{
     guild::Emoji,
-    id::{EmojiId, RoleId},
-    user::User,
+    id::{EmojiId, RoleId, UserId},
 };
 
+/// Represents a cached [`Emoji`].
+///
+/// [`Emoji`]: twilight_model::guild::Emoji
 #[derive(Clone, Debug, Eq, PartialEq, Serialize)]
 pub struct CachedEmoji {
+    /// ID of the Emoji.
     pub id: EmojiId,
+    /// Whether the emoji is animated.
     pub animated: bool,
+    /// Name of the Emoji.
     pub name: String,
+    /// Whether the emoji is managed.
     pub managed: bool,
+    /// Whether the emoji must be wrapped in colons.
     pub require_colons: bool,
+    /// List of roles allowed to use this emoji.
     pub roles: Vec<RoleId>,
-    pub user: Option<Arc<User>>,
+    /// ID of the user who created the emoji.
+    pub user_id: Option<UserId>,
+    /// Whether this emoji can be used.
+    ///
+    /// May be false due to loss of Server Boosts.
     pub available: bool,
 }
 
@@ -26,6 +37,7 @@ impl PartialEq<Emoji> for CachedEmoji {
             && self.name == other.name
             && self.require_colons == other.require_colons
             && self.roles == other.roles
+            && self.user_id == other.user.as_ref().map(|user| user.id)
             && self.available == other.available
     }
 }
@@ -44,7 +56,7 @@ mod tests {
         managed,
         require_colons,
         roles,
-        user
+        user_id
     );
     assert_impl_all!(CachedEmoji: Clone, Debug, Eq, PartialEq);
 
@@ -67,7 +79,7 @@ mod tests {
             managed: false,
             require_colons: true,
             roles: vec![],
-            user: None,
+            user_id: None,
             available: true,
         };
 
